{"error":false,"message":"

### USA Cycling December VRL Colorado Springs, CO Dec 2, 2020 - Dec 30, 2020 <\/h3> Last updated: Oct 21, 2022 Cross Country Ultra Endurance 12\/02\/2020 <\/b> Choose another day\/discipline <\/a>

Note: Ranking points are NOT upgrade points. An explanation of ranking points can be found here <\/a> . <\/p>

- XCU Men 1:55 Category A <\/a>
  Loading... <\/div> <\/li>
- XCU Men 1:55 Category B <\/a>
  Loading... <\/div> <\/li>
- XCU Men 1:55 Category C <\/a>
  Loading... <\/div> <\/li>
- XCU Men 1:55 Category D <\/a>
  Loading... <\/div> <\/li>
- XCU Men 5:45 Category A <\/a>
  Loading... <\/div> <\/li>
- XCU Men 5:45 Category B <\/a>
  Loading... <\/div> <\/li>
- XCU Women 5:45 Category B <\/a>
  Loading... <\/div> <\/li>
- XCU Men 5:45 Category C <\/a>
  Loading... <\/div> <\/li>
- XCU Women 5:45 Category C <\/a>
  Loading... <\/div> <\/li>
- XCU Men 5:45 Category D <\/a>
  Loading... <\/div> <\/li>
- XCU Women 5:45 Category D <\/a>
  Loading... <\/div> <\/li>
- XCU Men 8:55 Category A <\/a>
  Loading... <\/div> <\/li>
- XCU Men 8:55 Category B <\/a>
  Loading... <\/div> <\/li>
- XCU Men 8:55 Category C <\/a>
  Loading... <\/div> <\/li>
- XCU Men 8:55 Category D <\/a>
  Loading... <\/div> <\/li> <\/ul> <\/div>
  <\/div>"}